/**
 * Copyright (c) 2005-2010 Capgemini, 2005-2012 EBMWebsourcing, 2012-2015 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see <http://www.gnu.org/licenses/>
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.component.framework.api.exception;

import java.net.URI;

import javax.xml.namespace.QName;

/**
 * All exceptions based on this exception will be transform in a SOAP Fault.
 * <p>
 * The following rules are applied:
 * <ul>
 * <li>the fault code is set with the value returned by
 * {@link FaultException#getFaultCode()},</li>
 * <li>the fault string is set with the value returned by
 * {@link FaultException#getMessage()},</li>
 * <li>the fault actor is set with the value returned by
 * {@link FaultException#getFaultActor()},</li>
 * <li>the detail is set with the exception stack trace.</li>
 * </ul>
 * </p>
 * 
 * @author Christophe DENEUX - Capgemini Sud
 */
public class FaultException extends Exception {

    private static final long serialVersionUID = -1605535302049019555L;

    private QName faultCode = null;
    private URI faultActor = null;

    public FaultException(final QName faultCode, final String faultString,
            final URI faultActor) {
        super(faultString);
        this.faultCode = faultCode;
        this.faultActor = faultActor;
    }
    
    public FaultException(final QName faultCode, final String faultString, final URI faultActor, final Throwable cause) {
        super(faultString, cause);
        this.faultCode = faultCode;
        this.faultActor = faultActor;
    }

    public QName getFaultCode() {
        return this.faultCode;
    }

    public URI getFaultActor() {
        return this.faultActor;
    }
}
